@@ -7,6 +7,7 @@
 (custom-add-loads 'hypermedia '("htmlize"))
 (custom-add-loads 'hexl '("hexl"))
 (custom-add-loads 'languages '("crontab" "winmgr-mode" "xrdb-mode"))
+(custom-add-loads 'rtf '("rtf-support"))
 (custom-add-loads 'matching '("whitespace-mode"))
 (custom-add-loads 'processes '("ansi-color" "flyspell"))
 (custom-add-loads 'flyspell '("flyspell"))
@@ -19,7 +20,7 @@
 (custom-add-loads 'data '("hexl"))
 (custom-add-loads 'outlines '("whitespace-mode"))
 (custom-add-loads 'folding '("folding"))
-(custom-add-loads 'wp '("scribe"))
+(custom-add-loads 'wp '("rtf-support" "scribe"))
 (custom-add-loads 'scribe '("scribe"))
 (custom-add-loads 'filladapt '("filladapt"))
 (custom-add-loads 'tools '("autoinsert" "folding"))
